==> iamsystem-0.3.0.tar.gz: iamsystem-0.3.0/src/iamsystem/__init__.py <==
__all__ = [
    "Matcher",
    "IMatcher",
    "IBaseMatcher",
    "Annotation",
    "IAnnotation",
    "rm_nested_annots",
    "IStopwords",
    "Stopwords",
    "NoStopwords",
    "NegativeStopwords",
    "Keyword",
    "Entity",
    "Terminology",
    "Offsets",
    "Token",
    "TokenT",
    "TokenizerImp",
    "split_find_iter_closure",
    "french_tokenizer",
    "english_tokenizer",
    "lower_no_accents",
    "tokenize_and_order_decorator",
    "replace_annots",
    "Abbreviations",
    "CacheFuzzyAlgos",
    "ESpellWiseAlgo",
    "SpellWiseWrapper",
    "FuzzyRegex",
    "WordNormalizer",
    "token_is_upper_case",
    "BratDocument",
    "BratWriter",
    "BratEntity",
    "BratNote",
    "ContextFreeAlgo",
    "FuzzyAlgo",
    "IOffsets",
    "IKeyword",
    "IEntity",
    "NormLabelAlgo",
    "ISpan",
    "IToken",
    "ITokenizer",
    "IWords2ignore",
    "SimpleWords2ignore",
    "StringDistance",
    "SimStringWrapper",
    "ESimStringMeasure",
    "IBratFormatter",
    "TokenFormatter",
    "TokenStopFormatter",
    "SpanFormatter",
    "IndividualTokenFormatter",
]

from iamsystem.brat.adapter import BratDocument
from iamsystem.brat.adapter import BratEntity
from iamsystem.brat.adapter import BratNote
from iamsystem.brat.adapter import BratWriter
from iamsystem.brat.formatter import IndividualTokenFormatter
from iamsystem.brat.formatter import SpanFormatter
from iamsystem.brat.formatter import TokenFormatter
from iamsystem.brat.formatter import TokenStopFormatter
from iamsystem.fuzzy.abbreviations import Abbreviations
from iamsystem.fuzzy.abbreviations import token_is_upper_case
from iamsystem.fuzzy.api import ContextFreeAlgo
from iamsystem.fuzzy.api import FuzzyAlgo
from iamsystem.fuzzy.api import NormLabelAlgo
from iamsystem.fuzzy.api import StringDistance
from iamsystem.fuzzy.cache import CacheFuzzyAlgos
from iamsystem.fuzzy.norm_fun import WordNormalizer
from iamsystem.fuzzy.regex import FuzzyRegex
from iamsystem.fuzzy.simstring import ESimStringMeasure
from iamsystem.fuzzy.simstring import SimStringWrapper
from iamsystem.fuzzy.spellwise import ESpellWiseAlgo
from iamsystem.fuzzy.spellwise import SpellWiseWrapper
from iamsystem.fuzzy.util import IWords2ignore
from iamsystem.fuzzy.util import SimpleWords2ignore
from iamsystem.keywords.api import IEntity
from iamsystem.keywords.api import IKeyword
from iamsystem.keywords.collection import Terminology
from iamsystem.keywords.keywords import Entity
from iamsystem.keywords.keywords import Keyword
from iamsystem.matcher.annotation import Annotation
from iamsystem.matcher.annotation import replace_annots
from iamsystem.matcher.annotation import rm_nested_annots
from iamsystem.matcher.api import IAnnotation
from iamsystem.matcher.api import IBaseMatcher
from iamsystem.matcher.api import IBratFormatter
from iamsystem.matcher.api import IMatcher
from iamsystem.matcher.matcher import Matcher
from iamsystem.stopwords.api import IStopwords
from iamsystem.stopwords.negative import NegativeStopwords
from iamsystem.stopwords.simple import NoStopwords
from iamsystem.stopwords.simple import Stopwords
from iamsystem.tokenization.api import IOffsets
from iamsystem.tokenization.api import ISpan
from iamsystem.tokenization.api import IToken
from iamsystem.tokenization.api import ITokenizer
from iamsystem.tokenization.api import TokenT
from iamsystem.tokenization.normalize import lower_no_accents
from iamsystem.tokenization.token import Offsets
from iamsystem.tokenization.token import Token
from iamsystem.tokenization.tokenize import TokenizerImp
from iamsystem.tokenization.tokenize import english_tokenizer
from iamsystem.tokenization.tokenize import french_tokenizer
from iamsystem.tokenization.tokenize import split_find_iter_closure
from iamsystem.tokenization.tokenize import tokenize_and_order_decorator

==> iamsystem-0.4.0.tar.gz: iamsystem-0.4.0/src/iamsystem/__init__.py <==
__all__ = [
    "Matcher",
    "IMatcher",
    "IBaseMatcher",
    "EMatchingStrategy",
    "Annotation",
    "IAnnotation",
    "PrintAnnot",
    "rm_nested_annots",
    "IStopwords",
    "Stopwords",
    "NoStopwords",
    "NegativeStopwords",
    "Keyword",
    "Entity",
    "Terminology",
    "Offsets",
    "Token",
    "TokenT",
    "TokenizerImp",
    "split_find_iter_closure",
    "french_tokenizer",
    "english_tokenizer",
    "lower_no_accents",
    "tokenize_and_order_decorator",
    "replace_annots",
    "Abbreviations",
    "CacheFuzzyAlgos",
    "ESpellWiseAlgo",
    "SpellWiseWrapper",
    "FuzzyRegex",
    "WordNormalizer",
    "token_is_upper_case",
    "BratDocument",
    "BratWriter",
    "BratEntity",
    "BratNote",
    "ContextFreeAlgo",
    "FuzzyAlgo",
    "IOffsets",
    "IKeyword",
    "IEntity",
    "NormLabelAlgo",
    "ISpan",
    "IToken",
    "ITokenizer",
    "IWords2ignore",
    "SimpleWords2ignore",
    "StringDistance",
    "SimStringWrapper",
    "ESimStringMeasure",
    "IBratFormatter",
    "EBratFormatters",
    "ContSeqFormatter",
    "ContSeqStopFormatter",
    "SpanFormatter",
    "TokenFormatter",
]

__annot_version__ = "0.4.0"

from iamsystem.brat.adapter import BratDocument
from iamsystem.brat.adapter import BratEntity
from iamsystem.brat.adapter import BratNote
from iamsystem.brat.adapter import BratWriter
from iamsystem.brat.formatter import ContSeqFormatter
from iamsystem.brat.formatter import ContSeqStopFormatter
from iamsystem.brat.formatter import EBratFormatters
from iamsystem.brat.formatter import SpanFormatter
from iamsystem.brat.formatter import TokenFormatter
from iamsystem.fuzzy.abbreviations import Abbreviations
from iamsystem.fuzzy.abbreviations import token_is_upper_case
from iamsystem.fuzzy.api import ContextFreeAlgo
from iamsystem.fuzzy.api import FuzzyAlgo
from iamsystem.fuzzy.api import NormLabelAlgo
from iamsystem.fuzzy.api import StringDistance
from iamsystem.fuzzy.cache import CacheFuzzyAlgos
from iamsystem.fuzzy.norm_fun import WordNormalizer
from iamsystem.fuzzy.regex import FuzzyRegex
from iamsystem.fuzzy.simstring import ESimStringMeasure
from iamsystem.fuzzy.simstring import SimStringWrapper
from iamsystem.fuzzy.spellwise import ESpellWiseAlgo
from iamsystem.fuzzy.spellwise import SpellWiseWrapper
from iamsystem.fuzzy.util import IWords2ignore
from iamsystem.fuzzy.util import SimpleWords2ignore
from iamsystem.keywords.api import IEntity
from iamsystem.keywords.api import IKeyword
from iamsystem.keywords.collection import Terminology
from iamsystem.keywords.keywords import Entity
from iamsystem.keywords.keywords import Keyword
from iamsystem.matcher.annotation import Annotation
from iamsystem.matcher.annotation import replace_annots
from iamsystem.matcher.annotation import rm_nested_annots
from iamsystem.matcher.api import IAnnotation
from iamsystem.matcher.api import IBaseMatcher
from iamsystem.matcher.api import IBratFormatter
from iamsystem.matcher.api import IMatcher
from iamsystem.matcher.matcher import Matcher
from iamsystem.matcher.printannot import PrintAnnot
from iamsystem.matcher.strategy import EMatchingStrategy
from iamsystem.stopwords.api import IStopwords
from iamsystem.stopwords.negative import NegativeStopwords
from iamsystem.stopwords.simple import NoStopwords
from iamsystem.stopwords.simple import Stopwords
from iamsystem.tokenization.api import IOffsets
from iamsystem.tokenization.api import ISpan
from iamsystem.tokenization.api import IToken
from iamsystem.tokenization.api import ITokenizer
from iamsystem.tokenization.api import TokenT
from iamsystem.tokenization.normalize import lower_no_accents
from iamsystem.tokenization.token import Offsets
from iamsystem.tokenization.token import Token
from iamsystem.tokenization.tokenize import TokenizerImp
from iamsystem.tokenization.tokenize import english_tokenizer
from iamsystem.tokenization.tokenize import french_tokenizer
from iamsystem.tokenization.tokenize import split_find_iter_closure
from iamsystem.tokenization.tokenize import tokenize_and_order_decorator
